/*
 * public domain.
 */

#ifndef CRYPTO_API_H
#define CRYPTO_API_H

#include <stdint.h>
#include <stdlib.h>
#include <sys/random.h>

#define crypto_hash_sha512_BYTES 64U
#define crypto_sign_ed25519_SECRETKEYBYTES 64U
#define crypto_sign_ed25519_PUBLICKEYBYTES 32U
#define crypto_sign_ed25519_BYTES 64U

#define randombytes(buf, buf_len) getrandom((buf), (buf_len), GRND_RANDOM)

typedef int32_t crypto_int32;
typedef uint32_t crypto_uint32;

int crypto_hashblocks_sha512(unsigned char *, const unsigned char *,
                             unsigned long long);

int crypto_hash_sha512(unsigned char *, const unsigned char *,
                       unsigned long long);

int crypto_verify_32(const unsigned char *, const unsigned char *);

int crypto_sign_ed25519(unsigned char *, unsigned long long *,
                        const unsigned char *, unsigned long long,
                        const unsigned char *);

int crypto_sign_ed25519_open(unsigned char *, unsigned long long *,
                             const unsigned char *, unsigned long long,
                             const unsigned char *);

int crypto_sign_ed25519_keypair(unsigned char *, unsigned char *);

#endif /* CRYPTO_API_H */
